from datetime import datetime


def string_to_datetime(
    string: str, date_format: str = "%Y-%m-%dT%H:%M:%S.%f"
) -> datetime:
    return datetime.strptime(string, date_format)


def datetime_to_string(
    datetime_object: datetime, date_format: str = "%Y-%m-%dT%H:%M:%S.%f"
) -> str:
    return datetime_object.strftime(date_format)


def validate_dict(items: dict):
    for k, v in items.items():
        if v:
            accepted = accepted_values(key=k)
            if accepted:
                validate(key=k, value=v, accepted=accepted)


def accepted_values(key):
    if key == "interval":
        return ["hour", "day", "week", "month"]
    else:
        return []


def validate(key, value, accepted):
    if value not in accepted:
        raise Exception(f"Valid {key} options: {', '.join(accepted)}")



from enum import Enum


class Site(Enum):
    """Site enum."""

    RUMBLE_VIDEO = "rumble_video"
    RUMBLE_COMMENT = "rumble_comment"
    BITCHUTE_VIDEO = "bitchute_video"
    BITCHUTE_COMMENT = "bitchute_comment"
    RUTUBE_VIDEO = "rutube_video"
    RUTUBE_COMMENT = "rutube_comment"
    TIKTOK_VIDEO = "tiktok_video"
    TIKTOK_COMMENT = "tiktok_comment"
    LBRY_VIDEO = "lbry_video"
    LBRY_COMMENT = "lbry_comment"
    EIGHTKUN = "8kun"
    FOURCHAN = "4chan"
    GAB = "gab"
    PARLER = "parler"
    WIN = "win"
    POAL = "poal"
    TELEGRAM = "telegram"
    KIWIFARMS = "kiwifarms"
    GETTR = "gettr"
    WIMKIN = "wimkin"
    MEWE = "mewe"
    MINDS = "minds"
    VK = "vk"
    TRUTH_SOCIAL = "truth_social"



import logging


def info(message):
    logging.info(msg=message)


def error(message):
    logging.error(msg=message)


def warning(message):
    logging.warning(msg=message)


level_map = {"info": info, "error": error, "warning": warning}


def log(message: str, level: str = "info") -> None:
    """
    Log a message if verbose is enabled.

    :param message: Message to log
    :param level: info, error or warning
    :return: None
    :rtype: None
    """
    if level not in level_map.keys():
        level = "info"
    level_map[level](message)



from typing import Union

import objectrest

import smat.utils as utils
from smat.sites import Site


class API:
    _default_since = utils.string_to_datetime("2020-12-12T03:31:12.253311")
    _default_to = utils.string_to_datetime("2021-02-12T03:31:12.253311")

    def __init__(self, verbose: bool = False):
        self._requestor = objectrest.RequestHandler(
            base_url="https://api.smat-app.com/", log_requests=verbose
        )

    def get_content(
        self,
        term: str,
        site: Union[Site, str],
        limit: int = 10,
        since: utils.datetime = _default_since,
        until: utils.datetime = _default_to,
        esquery: bool = False,
    ) -> Union[dict, object]:
        if isinstance(site, Site):
            site = site.value
        params = {
            "term": term,
            "site": site,
            "limit": limit,
            "since": utils.datetime_to_string(since),
            "until": utils.datetime_to_string(until),
            "esquery": esquery,
        }
        utils.validate_dict(items=params)

        return self._requestor.get_json(url="content", params=params)

    def get_time_series(
        self,
        term: str,
        site: Union[Site, str],
        interval: str = "day",
        since: utils.datetime = _default_since,
        until: utils.datetime = _default_to,
        change_point: bool = False,
    ) -> Union[dict, object]:
        if isinstance(site, Site):
            site = site.value
        params = {
            "term": term,
            "site": site,
            "interval": interval,
            "since": utils.datetime_to_string(since),
            "until": utils.datetime_to_string(until),
            "changepoint": change_point,
        }
        utils.validate_dict(items=params)

        return self._requestor.get_json(url="timeseries", params=params)

    def get_activity(
        self,
        term: str,
        site: Union[Site, str],
        aggregate_by: str = None,
        since: utils.datetime = _default_since,
        until: utils.datetime = _default_to,
    ) -> Union[dict, object]:
        if isinstance(site, Site):
            site = site.value
        params = {
            "term": term,
            "site": site,
            "agg_by": aggregate_by,
            "since": utils.datetime_to_string(since),
            "until": utils.datetime_to_string(until),
        }
        utils.validate_dict(items=params)

        return self._requestor.get_json(url="activity", params=params)



import setuptools

__version__ = '0.2.0'

__title__ = "smat"
__author__ = 'Nate Harris'
__author_email__ = 'n8gr8gbln@gmail.com'
__github_username__ = "nwithan8"
__github_repo__ = "SMAT-API"
__copyright__ = "Copyright © 2022 - Nate Harris"
__license__ = 'GNU General Public License v3 (GPLv3)'
__description__ = "A Python client for SMAT's API"
__keywords__ = ["SMAT", "analysis", "social media", "tool", "online", "API"]

with open("README.md", "r") as fh:
    long_description = fh.read()


def python_versions():
    """Return a list of supported Python versions."""
    with open("PYTHON_VERSIONS") as f:
        versions = f.read().splitlines()
    version_strings = ['Programming Language :: Python :: 3']
    for version in versions:
        version_strings.append(f"Programming Language :: Python :: {version}")
    return version_strings


def python3_range():
    """Return a string of the supported Python version range."""
    with open("PYTHON_VERSIONS") as f:
        versions = f.read().splitlines()
    return f">={versions[0]}, <4"


REQUIREMENTS = [
    "objectrest==2.0.*",
    "packaging==21.3.*",
    "typing-extensions"
]

DEV_REQUIREMENTS = [
    "black",
    "flake8",
    "isort",
    "pytest-cov==3.*",
    "pytest-vcr==1.*",
    "pytest==7.*",
    "types-requests",
    "types-urllib3",
    "vcrpy==4.*",
]

classifiers = [
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Development Status :: 4 - Beta',
    # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',  # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'Topic :: Multimedia :: Video',
    'Topic :: Multimedia',
    'Topic :: Internet :: WWW/HTTP',
    'Operating System :: OS Independent'
]
classifiers.extend(python_versions())

setuptools.setup(
    name=__title__,
    packages=setuptools.find_packages(exclude=["tests"]),
    include_package_data=True,
    version=__version__,
    license=__license__,
    description=__description__,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=__author__,
    author_email=__author_email__,
    url=f'https://github.com/{__github_username__}/{__github_repo__}',
    download_url=f'https://github.com/{__github_username__}/{__github_repo__}/archive/refs/tags/{__version__}.tar.gz',
    keywords=__keywords__,
    install_requires=REQUIREMENTS,
    extras_require={
        "dev": DEV_REQUIREMENTS,
    },
    test_suite="test",
    classifiers=classifiers,
    python_requires=python3_range(),
)
